# Sparkslabs Update #8 : New Pyxie Release 0.1.25 - RELEASE FOCUS SUMMARY

# New Pyxie Release 0.1.25 - RELEASE FOCUS SUMMARY

## Released: DD Month YYYY

### In progress                  [ DELETE THIS SECTION ]

SPECIFIC IN PROGRESS             [ DELETE THIS SECTION ]

...

TARGET RELEASE DATE: 30/Nov/2016 [ DELETE THIS SECTION ]

Target Cards:                    [ DELETE THIS SECTION ]

     * 221. Initial spike support for function definitions. (no args, no return values) (VERY optimistic for this release)

     * 271. Transformation from python AST to C-CST exists/works - for simplest possible function

Hi,


[ PARA1 OVERVIEW OF RELEASE (delete this) ]

[ PARA2 MAIN USER FEATURE CHANGES (delete this) ]

[ PARA3 OTHER USER FEATURE CHANGES (delete this) ]

[ PARA4 INTERNAL CHANGES (delete this) ]



## Major Changes

[ If many, pick 3 THIS SECTION MUST FIT ON SCREEN. (delete this) ]

* 

* 

* 

[ Then overview of rest. (delete this) ]

Also reviewed the backlog to prune what's already been done, or updated.

### SPECIFIC PROFILE / INTERNAL CHANGES IF USEFUL (delete this otherwise)


## Changelog

[EXTRACTED FROM MAIN CHANGELOG (delete this) ]

### What's New?

* [EXTRACTED FROM MAIN CHANGELOG (delete this) ]


### What's been fixed?

* [EXTRACTED FROM MAIN CHANGELOG (delete this) ]


### Internal changes

* [EXTRACTED FROM MAIN CHANGELOG (delete this) ]

### Other

* [EXTRACTED FROM MAIN CHANGELOG (delete this) ]


## Feedback?

As usual, feedback is welcome.  What would you like to see?  Would you like
more detail, less detail?  Suggestions for project direction also very
welcome.


### Since last release

I had this feedback from the last release:



## Finally

As mentioned before, development of pyxie is strictly on my own time with
my own resources, and therefore development is not as fast as I'd like in
an ideal world.

If you'd like to help, please get in touch.

I've considered a kickstarter or IndieGoGo project to speed things up.
I'd also consider a patreon account. If there was one, do you think you
would contribute back that way, if you can't contribute code?

Whether or not you would consider it yourself, how much would you consider
reasonable to pledge? (This isn't a call to do so, but really an open
question - I do see a reasonable amount of traffic to my site from unique
users clearly looking for a python based mechanism for working with
arduinos natively)


## Availability

This release is available on github, pypi and my ubuntu ppa on launchpad.

* https://github.com/sparkslabs/pyxie
* https://pypi.python.org/pypi/pyxie/
* https://launchpad.net/~sparkslabs/+archive/ubuntu/packages

Dev plans:

* http://www.sparkslabs.com/pyxie/dev-status.html

As usual, and and all feedback welcome!


Michael. (@sparks_rd - https://twitter.com/sparks_rd)
